/* menubars.c -- Functions which draw the menu bars for this program.
 *
 * Bryan Herger (hergeb@rpi.edu)
 * Part of my file manager.  Hacked from my Comp. Graphics term project.
 */

#include <stdio.h>
#include <unistd.h>
#include <X11/Xlib.h>
#include <X11/X.h>
#include <Xm/Xm.h>
#include <Xm/CascadeB.h>
#include <Xm/Form.h>
#include <Xm/MainW.h>
#include <Xm/PanedW.h>
#include <Xm/PushB.h>
#include <Xm/RowColumn.h>
#include <Xm/Separator.h>
#include <Xm/Text.h>
#include <Xm/MessageB.h>
#include "defines.h"
#include "menucallback.h"

/* Why are these out here?... */
Widget share_pulldown, smb_config, smb_share, smb_listshares;
Widget dir_upone;

/* Set in main.c, this is the uid and gid of the program. */
extern uid_t local_uid;
extern gid_t local_gid;

/* Create that top menu bar.  Later I will add a toolbar and such.
 * This function creates the menu bar, all pulldowns, and sets callbacks
 * to menucallack.c */
Widget CreateMenuBar(Widget parent)
{
  Widget menubar_widget;
  Widget file_pulldown, dir_pulldown, toolbar_pulldown, help_pulldown;
  Widget file_run, file_copy, file_move, file_delete, file_info, file_exit;
  Widget file_sep1, file_sep2, file_sep3, file_find;
  Widget dir_create, dir_separator, dir_goto, dir_home; 
  Widget smb_separator, share_nfs;
  Widget toolbar_add, toolbar_remove;
  Widget help_button, help_general, help_index, help_sep, help_about;

  menubar_widget = XmCreateMenuBar(parent, "menubar", NULL, 0);

  XtManageChild(menubar_widget);

  file_pulldown = XmCreatePulldownMenu(menubar_widget, "file_pulldown", NULL, 0);

  file_run = XtVaCreateManagedWidget("file_run", xmPushButtonWidgetClass,
				     file_pulldown, NULL);
  XtAddCallback(file_run, XmNactivateCallback, MenuCallback,
		(XtPointer) FILE_MENU_RUN);
  XtVaSetValues(file_run, XmNlabelString, XmStringCreateSimple("Run..."),
		NULL);
  file_copy = XtVaCreateManagedWidget("file_copy", xmPushButtonWidgetClass,
				     file_pulldown, NULL);
  XtAddCallback(file_copy, XmNactivateCallback, MenuCallback,
		(XtPointer) FILE_MENU_COPY);
  XtVaSetValues(file_copy, XmNlabelString, XmStringCreateSimple("Copy"),
		NULL);
  file_move = XtVaCreateManagedWidget("file_move", xmPushButtonWidgetClass,
				     file_pulldown, NULL);
  XtAddCallback(file_move, XmNactivateCallback, MenuCallback,
		(XtPointer) FILE_MENU_MOVE);
  XtVaSetValues(file_move, XmNlabelString, XmStringCreateSimple("Move"),
		NULL);
  file_delete = XtVaCreateManagedWidget("file_delete", xmPushButtonWidgetClass,
				     file_pulldown, NULL);
  XtAddCallback(file_delete, XmNactivateCallback, MenuCallback,
		(XtPointer) FILE_MENU_DELETE);
  XtVaSetValues(file_delete, XmNlabelString, XmStringCreateSimple("Delete"),
		NULL);
  file_info = XtVaCreateManagedWidget("file_info", xmPushButtonWidgetClass,
				     file_pulldown, NULL);
  XtAddCallback(file_info, XmNactivateCallback, MenuCallback,
		(XtPointer) FILE_MENU_INFO);
  XtVaSetValues(file_info, XmNlabelString, XmStringCreateSimple("Info"),
		NULL);
  file_find = XtVaCreateManagedWidget("file_find", xmPushButtonWidgetClass,
				     file_pulldown, NULL);
  XtAddCallback(file_find, XmNactivateCallback, MenuCallback,
		(XtPointer) FILE_MENU_FIND);
  XtVaSetValues(file_find, XmNlabelString, XmStringCreateSimple("Find..."),
		NULL);
  file_exit = XtVaCreateManagedWidget("file_exit", xmPushButtonWidgetClass,
				     file_pulldown, XmNmnemonic, 'X', NULL);
  XtAddCallback(file_exit, XmNactivateCallback, MenuCallback,
		(XtPointer) FILE_MENU_EXIT);
  XtVaSetValues(file_exit, XmNlabelString, XmStringCreateSimple("Exit"),
		NULL);

  dir_pulldown = XmCreatePulldownMenu(menubar_widget, "dir_pulldown", NULL, 0);
  dir_create = XtVaCreateManagedWidget("dir_create", 
				       xmPushButtonWidgetClass,
				       dir_pulldown, NULL);
  XtAddCallback(dir_create, XmNactivateCallback, MenuCallback, 
		(XtPointer) DIR_CREATE);
  XtVaSetValues(dir_create, XmNlabelString, 
		XmStringCreateSimple("Create..."), NULL);
  dir_separator = XtVaCreateManagedWidget("dir_sep_1",
					  xmSeparatorWidgetClass,
					  dir_pulldown, NULL);
  dir_goto = XtVaCreateManagedWidget("dir_goto", 
				     xmPushButtonWidgetClass,
				     dir_pulldown, NULL);
  XtAddCallback(dir_goto, XmNactivateCallback, MenuCallback,
		(XtPointer) DIR_GOTO);
  XtVaSetValues(dir_goto, XmNlabelString, 
		XmStringCreateSimple("Goto..."), NULL);
  dir_home = XtVaCreateManagedWidget("dir_home", 
				     xmPushButtonWidgetClass,
				     dir_pulldown, NULL);
  XtAddCallback(dir_home, XmNactivateCallback, MenuCallback, 
		(XtPointer) DIR_HOME);
  XtVaSetValues(dir_home, XmNlabelString, 
		XmStringCreateSimple("Home"), NULL);
  dir_upone = XtVaCreateManagedWidget("dir_upone", 
				      xmPushButtonWidgetClass,
				      dir_pulldown, NULL);
  XtAddCallback(dir_upone, XmNactivateCallback, MenuCallback, 
		(XtPointer) DIR_UPONE);
  XtVaSetValues(dir_upone, XmNlabelString, 
		XmStringCreateSimple("Up"), NULL);

  share_pulldown = XmCreatePulldownMenu(menubar_widget, "share_pulldown", NULL, 0);
  smb_share = XtVaCreateManagedWidget("share_smb_addshare", 
				      xmPushButtonWidgetClass,
				      share_pulldown, NULL);
  XtAddCallback(smb_share, XmNactivateCallback, MenuCallback, 
		(XtPointer) SHARE_SMB_ADDSHARE);
  XtVaSetValues(smb_share, XmNlabelString, 
		XmStringCreateSimple("Add SMB share"), NULL);
  smb_listshares = XtVaCreateManagedWidget("share_smb_listshares", 
					   xmPushButtonWidgetClass,
					   share_pulldown, NULL);
  XtAddCallback(smb_listshares, XmNactivateCallback, MenuCallback,
		(XtPointer) SHARE_SMB_LISTSHARES);
  XtVaSetValues(smb_listshares, XmNlabelString, 
		XmStringCreateSimple("List SMB shares"), NULL);
  smb_separator = XtVaCreateManagedWidget("share_sep_1",
					 xmSeparatorWidgetClass,
					 share_pulldown, NULL);
  smb_config = XtVaCreateManagedWidget("share_smb_config", 
				       xmPushButtonWidgetClass,
				       share_pulldown, NULL);
  XtAddCallback(smb_config, XmNactivateCallback, MenuCallback, 
		(XtPointer) SHARE_SMB_CONFIG);
  XtVaSetValues(smb_config, XmNlabelString, 
		XmStringCreateSimple("SMB Server..."), NULL);
  share_nfs = XtVaCreateManagedWidget("share_nfs_config", 
				      xmPushButtonWidgetClass,
				      share_pulldown, NULL);
  XtAddCallback(share_nfs, XmNactivateCallback, MenuCallback, 
		(XtPointer) SHARE_NFS_CONFIG);
  XtVaSetValues(share_nfs, XmNlabelString, 
		XmStringCreateSimple("NFS Server..."), NULL);

  toolbar_pulldown = XmCreatePulldownMenu(menubar_widget, "toolbar_pulldown", NULL, 0);
  toolbar_add = XtVaCreateManagedWidget("toolbar_add", xmPushButtonWidgetClass,
					toolbar_pulldown, NULL);
  XtAddCallback(toolbar_add, XmNactivateCallback, MenuCallback,
		(XtPointer) TOOLBAR_MENU_ADD);
  XtVaSetValues(toolbar_add, XmNlabelString,
		XmStringCreateSimple("Add item"), NULL);
  toolbar_remove = XtVaCreateManagedWidget("toolbar_remove", xmPushButtonWidgetClass,
					toolbar_pulldown, NULL);
  XtAddCallback(toolbar_remove, XmNactivateCallback, MenuCallback,
		(XtPointer) TOOLBAR_MENU_REMOVE);
  XtVaSetValues(toolbar_remove, XmNlabelString,
		XmStringCreateSimple("Remove item..."), NULL);

  help_pulldown = XmCreatePulldownMenu(menubar_widget, "help_pulldown", 
				       NULL, 0);
  help_general = XtVaCreateManagedWidget("help_general", 
					 xmPushButtonWidgetClass,
					 help_pulldown, NULL);
  XtAddCallback(help_general, XmNactivateCallback, MenuCallback,
		(XtPointer) HELP_MENU_GENERAL);
  XtVaSetValues(help_general, XmNlabelString,
		XmStringCreateSimple("General Help"), NULL);
  /*  help_index = XtVaCreateManagedWidget("help_index", xmPushButtonWidgetClass,
				       help_pulldown, NULL);
  XtAddCallback(help_index, XmNactivateCallback, MenuCallback,
		(XtPointer) HELP_MENU_INDEX);
  XtVaSetValues(help_index, XmNlabelString,
		XmStringCreateSimple("Index"), NULL); */
  help_sep = XtVaCreateManagedWidget("help_sep", xmSeparatorWidgetClass,
				     help_pulldown, NULL);
  help_about = XtVaCreateManagedWidget("help_about", xmPushButtonWidgetClass,
				       help_pulldown, NULL);
  XtAddCallback(help_about, XmNactivateCallback, MenuCallback,
		(XtPointer) HELP_MENU_ABOUT);
  XtVaSetValues(help_about, XmNlabelString,
		XmStringCreateSimple("About..."), NULL);

  XtVaCreateManagedWidget("File", xmCascadeButtonWidgetClass, menubar_widget,
			  XmNsubMenuId, file_pulldown, NULL);
  XtVaCreateManagedWidget("Directory", xmCascadeButtonWidgetClass, 
			  menubar_widget, XmNsubMenuId, dir_pulldown, NULL);
  /* We went through all that work to make the 'Share' pulldown, but only
   * root can use it, so don't display it for anyone else */
  if (local_uid == 0 && local_gid ==0)
    XtVaCreateManagedWidget("Share", xmCascadeButtonWidgetClass, 
			    menubar_widget, XmNsubMenuId, share_pulldown, 
			    NULL);
  /*  XtVaCreateManagedWidget("Applications", xmCascadeButtonWidgetClass,
			  menubar_widget, XmNsubMenuId, toolbar_pulldown,
			  NULL); */

  help_button = XtVaCreateManagedWidget("Help", xmCascadeButtonWidgetClass,
					menubar_widget, XmNsubMenuId,
					help_pulldown, NULL);

  XtVaSetValues(menubar_widget, XmNmenuHelpWidget, help_button, NULL);

  return(menubar_widget);
}
